@@ -8,8 +8,8 @@ from plugwise.nodes.circle import PlugwiseCircle
 
 
 class PlugwiseStealth(PlugwiseCircle):
-    """provides interface to the Plugwise Stealth nodes
-    """
+    """provides interface to the Plugwise Stealth nodes"""
 
     def __init__(self, mac, address, stick):
         super().__init__(mac, address, stick)
+
